@@ -55,26 +55,29 @@ class RequestsTool():
 
     def get(self, url, params=None):
         response = requests.get(self._get_url(url) , headers=self._get_headers(), params=params)
-        token = response.headers['Authorization']
-        if token:
-            oc = OnebrainConfig()
-            oc.set_token(token)
-        return response.json()
+        if 'Authorization' in response.headers:
+            token = response.headers['Authorization']
+            if token:
+                oc = OnebrainConfig()
+                oc.set_token(token)
+            return response.json()
 
     def post(self, url, data=None):
         response = requests.post(self._get_url(url), headers=self._get_headers(), json=data)
-        token = response.headers['Authorization']
-        if token:
-            oc = OnebrainConfig()
-            oc.set_token(token)
+        if 'Authorization' in response.headers:
+            token = response.headers['Authorization']
+            if token:
+                oc = OnebrainConfig()
+                oc.set_token(token)
         return response.json()
 
     def put(self, url, data=None):
         response = requests.put(self._get_url(url), headers=self._get_headers(), json=data)
-        token = response.headers['Authorization']
-        if token:
-            oc = OnebrainConfig()
-            oc.set_token(token)
+        if 'Authorization' in response.headers:
+            token = response.headers['Authorization']
+            if token:
+                oc = OnebrainConfig()
+                oc.set_token(token)
         return response.json()
 
     def upload(self, url, data=None):
@@ -83,19 +86,21 @@ class RequestsTool():
         num = num + 1
         if num % 100 == 0:
             num = 0
-            token =response.headers['Authorization']
-            if token:
-                oc = OnebrainConfig()
-                oc.set_token(token)
+            if 'Authorization' in response.headers:
+                token =response.headers['Authorization']
+                if token:
+                    oc = OnebrainConfig()
+                    oc.set_token(token)
         return response.json()
 
     def delete(self, url):
         response = requests.delete(self._get_url(url), headers=self._get_headers())
-        token = response.headers['Authorization']
-        if token:
-            oc = OnebrainConfig()
-            oc.set_token(token)
-        return response.json()
+        if 'Authorization' in response.headers:
+            token = response.headers['Authorization']
+            if token:
+                oc = OnebrainConfig()
+                oc.set_token(token)
+            return response.json()
 
 def _test_get(token):
     r = RequestsTool(token)
